==> enterprisemodules-wls_config-3.5.0.tar.gz: enterprisemodules-wls_config-3.5.0/lib/puppet/type/wls_jms_security_policy.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_jms_security_policy) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc 'This resource allows you to manage security authorization policies in an WebLogic Security Realm.'

    ensurable

    to_get_raw_resources do
      Puppet.info "index #{name}"
      environment = { 'action' => 'index', 'type' => 'wls_jms_security_policy' }
      wlst template('wls_config/wls_jms_security_policy/index.py.erb', binding), environment
    end

    on_create do
      wlst_action = 'create'
      Puppet.info "create #{name}"
      wlst template('wls_config/wls_jms_security_policy/create.py.erb', binding)
      nil
    end

    on_modify do
      wlst_action = 'modify'
      Puppet.info "modify #{name}"
      wlst template('wls_config/wls_jms_security_policy/modify.py.erb', binding)
      nil
    end

    on_destroy do
      Puppet.info "destroy #{name}"
      wlst template('wls_config/wls_jms_security_policy/destroy.py.erb', binding)
      nil
    end

    parameter :domain
    parameter :name
    parameter :jmsmodule
    parameter :destinationtype
    parameter :resourcename
    parameter :action
    parameter :authorizationprovider
    parameter :timeout
    property  :policyexpression

    add_title_attributes(:jmsmodule, :resourcename, :action) do
      /(.+):(.+):(.+)$/
    end

    child_of(:wls_jms_queue) { "#{domain}/#{jmsmodule}:#{resourcename}" if destinationtype == :queue }
    child_of(:wls_jms_topic) { "#{domain}/#{jmsmodule}:#{resourcename}" if destinationtype == :topic }
  end
end

==> enterprisemodules-wls_config-3.7.1.tar.gz: enterprisemodules-wls_config-3.7.1/lib/puppet/type/wls_jms_security_policy.rb <==
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift File.join(File.dirname(__FILE__), '../..')
require 'puppet_x/enterprisemodules/weblogic/core'

module Puppet
  Type.newtype(:wls_jms_security_policy) do
    include Puppet_X::EnterpriseModules::WebLogic::Type

    desc 'This resource allows you to manage security authorization policies in an WebLogic Security Realm.'

    ensurable

    to_get_raw_resources do
      Puppet.info "index #{name}"
      environment = { 'action' => 'index', 'type' => 'wls_jms_security_policy' }
      wlst template('wls_config/wls_jms_security_policy/index.py.erb', binding), environment
    end

    on_create do
      wlst_action = 'create'
      Puppet.info "create #{name}"
      wlst template('wls_config/wls_jms_security_policy/create.py.erb', binding)
      nil
    end

    on_modify do
      wlst_action = 'modify'
      Puppet.info "modify #{name}"
      wlst template('wls_config/wls_jms_security_policy/modify.py.erb', binding)
      nil
    end

    on_destroy do
      Puppet.info "destroy #{name}"
      wlst template('wls_config/wls_jms_security_policy/destroy.py.erb', binding)
      nil
    end

    parameter :domain
    parameter :name
    parameter :jmsmodule
    parameter :destinationtype
    parameter :resourcename
    parameter :action
    parameter :authorizationprovider
    parameter :timeout
    property  :policyexpression

    add_title_attributes(:jmsmodule, :resourcename, :action) do
      /(.+):(.+):(.+)$/
    end

    child_of(:wls_jms_queue) { "#{domain}/#{jmsmodule}:#{resourcename}" if destinationtype.to_s == 'queue' }
    child_of(:wls_jms_topic) { "#{domain}/#{jmsmodule}:#{resourcename}" if destinationtype.to_s == 'topic' }
  end
end
